@@ -1,7 +1,7 @@
 """Messaging Framework for Python"""
 from __future__ import absolute_import
 
-VERSION = (2, 2, 2)
+VERSION = (2, 2, 3)
 __version__ = '.'.join(map(str, VERSION[0:3])) + ''.join(VERSION[3:])
 __author__ = 'Ask Solem'
 __contact__ = 'ask@celeryproject.org'
@@ -26,10 +26,12 @@ if sys.version_info < (2, 5):  # pragma: no cover
 from types import ModuleType
 
 all_by_module = {
-    'kombu.connection': ['BrokerConnection', 'Connection'],
-    'kombu.entity': ['Exchange', 'Queue'],
-    'kombu.messaging': ['Consumer', 'Producer'],
-    'kombu.pools': ['connections', 'producers'],
+    'kombu.connection': ['Connection', 'BrokerConnection'],
+    'kombu.entity':     ['Exchange', 'Queue'],
+    'kombu.messaging':  ['Consumer', 'Producer'],
+    'kombu.pools':      ['connections', 'producers'],
+    'kombu.utils.url':  ['parse_url'],
+    'kombu.common':     ['eventloop', 'uuid']
 }
 
 object_origins = {}
