@@ -26,7 +26,8 @@ from .utils import uuid
 
 __all__ = ['Broadcast', 'maybe_declare', 'uuid',
            'itermessages', 'send_reply', 'isend_reply',
-           'collect_replies', 'insured', 'ipublish']
+           'collect_replies', 'insured', 'ipublish', 'drain_consumer',
+           'eventloop']
 
 insured_logger = Log('kombu.insurance')
 
@@ -168,13 +169,16 @@ def isend_reply(pool, exchange, req, msg, props, **retry_policy):
 def collect_replies(conn, channel, queue, *args, **kwargs):
     no_ack = kwargs.setdefault('no_ack', True)
     received = False
-    for body, message in itermessages(conn, channel, queue, *args, **kwargs):
-        if not no_ack:
-            message.ack()
-        received = True
-        yield body
-    if received:
-        channel.after_reply_message_received(queue.name)
+    try:
+        for body, message in itermessages(conn, channel, queue,
+                                          *args, **kwargs):
+            if not no_ack:
+                message.ack()
+            received = True
+            yield body
+    finally:
+        if received:
+            channel.after_reply_message_received(queue.name)
 
 
 def _ensure_errback(exc, interval):
