@@ -32,14 +32,13 @@ from .utils.url import parse_url
 _LOG_CONNECTION = os.environ.get('KOMBU_LOG_CONNECTION', False)
 _LOG_CHANNEL = os.environ.get('KOMBU_LOG_CHANNEL', False)
 
-__all__ = ['parse_url', 'BrokerConnection', 'Resource',
-           'ConnectionPool', 'ChannelPool']
+__all__ = ['Connection', 'ConnectionPool', 'ChannelPool']
 URI_PASSTHROUGH = frozenset(['sqla', 'sqlalchemy'])
 
 logger = get_logger(__name__)
 
 
-class BrokerConnection(object):
+class Connection(object):
     """A connection to the broker.
 
     :param URL:  Connection URL.
@@ -102,14 +101,14 @@ class BrokerConnection(object):
                   'port': port, 'insist': insist, 'ssl': ssl,
                   'transport': transport, 'connect_timeout': connect_timeout,
                   'login_method': login_method}
-        if hostname and '://' in hostname \
-                and transport not in URI_PASSTHROUGH:
+        if hostname and '://' in hostname:
             if '+' in hostname[:hostname.index('://')]:
                 # e.g. sqla+mysql://root:masterkey@localhost/
                 params['transport'], params['hostname'] = hostname.split('+')
                 self.uri_prefix = params['transport']
             else:
-                params.update(parse_url(hostname))
+                if transport not in URI_PASSTHROUGH:
+                    params.update(parse_url(hostname))
         self._init_params(**params)
 
         # backend_cls argument will be removed shortly.
@@ -386,10 +385,10 @@ class BrokerConnection(object):
         transport_cls = self.transport_cls or 'amqp'
         transport_cls = {AMQP_ALIAS: 'amqp'}.get(transport_cls, transport_cls)
         D = self.transport.default_connection_params
-        hostname = self.hostname
+        hostname = self.hostname or D.get('hostname')
         if self.uri_prefix:
             hostname = '%s+%s' % (self.uri_prefix, hostname)
-        info = (('hostname', hostname or D.get('hostname')),
+        info = (('hostname', hostname),
                 ('userid', self.userid or D.get('userid')),
                 ('password', self.password or D.get('password')),
                 ('virtual_host', self.virtual_host or D.get('virtual_host')),
@@ -552,7 +551,7 @@ class BrokerConnection(object):
 
     def __repr__(self):
         """``x.__repr__() <==> repr(x)``"""
-        return '<BrokerConnection: %s at 0x%x>' % (self.as_uri(), id(self))
+        return '<Connection: %s at 0x%x>' % (self.as_uri(), id(self))
 
     def __copy__(self):
         """``x.__copy__() <==> copy(x)``"""
@@ -634,7 +633,7 @@ class BrokerConnection(object):
     @property
     def is_evented(self):
         return getattr(self.transport, 'on_poll_start', None)
-Connection = BrokerConnection
+BrokerConnection = Connection
 
 
 class Resource(object):
@@ -851,6 +850,6 @@ class ChannelPool(Resource):
 def maybe_channel(channel):
     """Returns channel, or returns the default_channel if it's a
     connection."""
-    if isinstance(channel, BrokerConnection):
+    if isinstance(channel, Connection):
         return channel.default_channel
     return channel
